﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Xamarin.Forms;

namespace GaugePage
{
    public class Carrousel : CarouselPage
    {
        ObservableCollection<GroupReward> testData = null;

        public Carrousel()
        {
            NavigationPage.SetBackButtonTitle(this, "Back");
            testData = MakeTestData();
        }

        protected override void OnAppearing()
        {
            if (Children.Count != testData.Count)
            {
                Children.Clear();
                var pageId = 0;
                foreach (GroupReward gr in testData)
                {
                    Children.Add(new GaugePage(gr, pageId, testData.Count) { Title = pageId.ToString(), BackgroundColor = Color.Blue });
                    pageId++;
                }
            }
        }

        public ObservableCollection<GroupReward> MakeTestData()
        {
            var data = new ObservableCollection<GroupReward>();
            data.Add(new GroupReward()
            {
                SponsorInfo = new SponsorInfo() { SponsorCode = "Code", SponsorName = "Name", PointTarget = 100 },
                CurrentEarnedPoints = 45,
            });
            data.Add(new GroupReward()
            {
                SponsorInfo = new SponsorInfo() { SponsorCode = "Code2", SponsorName = "Name2", PointTarget = 5 },
                CurrentEarnedPoints = 1,
            });
            return data;
        }
    }

    public class GroupReward
    {
        public GroupReward()
        {
            RewardInfo = new ObservableCollection<RewardInfo>();
        }
        public int CalendarYear { get; set; }

        // user specific fields
        public int CurrentEarnedPoints { get; set; }
        public int NumTimesPointTargetMet { get; set; }
        public int TotalPointsEarned { get; set; }
        public DateTime? TargetLastMet { get; set; }

        public SponsorInfo SponsorInfo { get; set; }
        public ObservableCollection<RewardInfo> RewardInfo { get; set; }
        public bool RewardsFound { get; set; }
    }

    public class SponsorInfo
    {
        public SponsorInfo()
        {
            PointRules = new List<string>();
        }

        public bool IsPayingIncentive { get; set; }
        public string SponsorCode { get; set; }
        public string SponsorName { get; set; }
        public string Status { get; set; }
        public string Summary { get; set; }
        public string ProgramUri { get; set; }
        public string ImageFile { get; set; }
        public int PointTarget { get; set; }
        public List<string> PointRules { get; set; }
    }

    public class RewardInfo
    {
        public string UniqueId { get; set; }
        public DateTime EarnedDate { get; set; }
        public string Title { get; set; }
        public string SubTitle { get; set; }
        public string Status { get; set; }
        public string Body { get; set; }
        public List<RewardField> Fields { get; set; }
        public string Footer { get; set; }
        public RewardDetail Detail { get; set; }
    }

    public class RewardDetail
    {
        public string Title { get; set; }
        public string SubTitle { get; set; }
        public string Body { get; set; }
        public List<RewardField> Fields { get; set; }
        public string Footer { get; set; }
        public string PromoCode { get; set; }
        public string RedemptionInstructions { get; set; }
    }

    public class RewardField
    {
        public string Title { get; set; }
        public string Value { get; set; }
        public string Footer { get; set; }
    }
}
